==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-pane-drag-end-event-args.js <==
import { PaneDragEndEventArgs as PaneDragEndEventArgs_internal } from "./PaneDragEndEventArgs";
var IgrPaneDragEndEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPaneDragEndEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrPaneDragEndEventArgs.prototype.createImplementation = function () {
        return new PaneDragEndEventArgs_internal();
    };
    Object.defineProperty(IgrPaneDragEndEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPaneDragEndEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPaneDragEndEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrPaneDragEndEventArgs.prototype, "detail", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            if (!this.i.a.externalObject) {
                var e = new IgrPaneDragEndEventArgs();
                e._implementation = this.i.a;
                this.i.a.externalObject = e;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPaneDragEndEventArgs;
}());
export { IgrPaneDragEndEventArgs };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-pane-drag-end-event-args.js <==
import { IgrPaneDragEndEventArgsDetail } from "./igr-pane-drag-end-event-args-detail";
import { PaneDragEndEventArgs as PaneDragEndEventArgs_internal } from "./PaneDragEndEventArgs";
var IgrPaneDragEndEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPaneDragEndEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrPaneDragEndEventArgs.prototype.createImplementation = function () {
        return new PaneDragEndEventArgs_internal();
    };
    Object.defineProperty(IgrPaneDragEndEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPaneDragEndEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPaneDragEndEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrPaneDragEndEventArgs.prototype, "detail", {
        get: function () {
            var r = this.i.b;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrPaneDragEndEventArgsDetail();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.b = null : this.i.b = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPaneDragEndEventArgs;
}());
export { IgrPaneDragEndEventArgs };
